@@ -24,7 +24,8 @@ def basic_table(read_path, read_type='csv', sheet_name=None, columns_to_keep=Non
         if remove_NAN_col == 'all':
             df_basic_table = df_basic_table[df_basic_table[columns_rename].notna()]
         else:
-            df_basic_table = df_basic_table[df_basic_table[remove_NAN_col].notna()]
+            for col in remove_NAN_col:
+                df_basic_table = df_basic_table[df_basic_table[col].notna()]
 
     if pre_agg_math_columns is not None:
         for new_column_name, math_expression in pre_agg_math_columns.items():
